==> haskell-tasty-inspection-testing-0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-inspection-testing
version:              0.1
visibility:           public
id:                   tasty-inspection-testing-0.1-Cu52SxyStknEvifN8p1nnU
key:                  tasty-inspection-testing-0.1-Cu52SxyStknEvifN8p1nnU
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  f67470be5846f038b1bc288059cb7430
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-inspection-testing-0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-inspection-testing-0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/tasty-inspection-testing-0.1

hs-libraries:         HStasty-inspection-testing-0.1-Cu52SxyStknEvifN8p1nnU
depends:
    base-4.15.0.0 ghc-9.0.1
    inspection-testing-0.4.6.0-3fH2HkfmYhRh4BwvE9BdL
    tasty-1.4.2-DmpA164azzOJtaMxnfJrIk template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-inspection-testing-0.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-inspection-testing
version:              0.1
visibility:           public
id:                   tasty-inspection-testing-0.1-F1X50hxrl9e8zWknOWjzUr
key:                  tasty-inspection-testing-0.1-F1X50hxrl9e8zWknOWjzUr
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  c0ea70fc34e34d88390ffb1c0d2f47e7
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-inspection-testing-0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-inspection-testing-0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/tasty-inspection-testing-0.1

hs-libraries:         HStasty-inspection-testing-0.1-F1X50hxrl9e8zWknOWjzUr
depends:
    base-4.15.0.0 ghc-9.0.1
    inspection-testing-0.4.6.0-3fH2HkfmYhRh4BwvE9BdL
    tasty-1.4.2-5duO9gOThhmH0ll4XisXWn template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
